==> kafka-3.7.2-src.tgz: kafka-3.7.2-src/storage/src/test/java/org/apache/kafka/tiered/storage/actions/EraseBrokerStorageAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.tiered.storage.actions;

import org.apache.kafka.tiered.storage.TieredStorageTestAction;
import org.apache.kafka.tiered.storage.TieredStorageTestContext;

import java.io.IOException;
import java.io.PrintStream;

public final class EraseBrokerStorageAction implements TieredStorageTestAction {

    private final int brokerId;

    public EraseBrokerStorageAction(int brokerId) {
        this.brokerId = brokerId;
    }

    @Override
    public void doExecute(TieredStorageTestContext context) throws IOException {
        context.eraseBrokerStorage(brokerId);
    }

    @Override
    public void describe(PrintStream output) {
        output.println("erase-broker-storage: " + brokerId);
    }
}

==> kafka-4.1.1-src.tgz: kafka-4.1.1-src/storage/src/test/java/org/apache/kafka/tiered/storage/actions/EraseBrokerStorageAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.tiered.storage.actions;

import org.apache.kafka.tiered.storage.TieredStorageTestAction;
import org.apache.kafka.tiered.storage.TieredStorageTestContext;

import java.io.FilenameFilter;
import java.io.IOException;
import java.io.PrintStream;

public final class EraseBrokerStorageAction implements TieredStorageTestAction {

    private final int brokerId;
    private final FilenameFilter filenameFilter;
    private final boolean isStopped;

    public EraseBrokerStorageAction(int brokerId) {
        this(brokerId, (dir, name) -> true, false);
    }

    public EraseBrokerStorageAction(int brokerId,
                                    FilenameFilter filenameFilter,
                                    boolean isStopped) {
        this.brokerId = brokerId;
        this.filenameFilter = filenameFilter;
        this.isStopped = isStopped;
    }

    @Override
    public void doExecute(TieredStorageTestContext context) throws IOException {
        context.eraseBrokerStorage(brokerId, filenameFilter, isStopped);
    }

    @Override
    public void describe(PrintStream output) {
        output.println("erase-broker-storage: " + brokerId + ", isStopped: " + isStopped +
                ", filenameFilter: " + filenameFilter);
    }
}
